@@ -44,10 +44,10 @@ class Services_Hatena {
     public function Services_hatena() {}
 
     /**
-     * Attempts to return a concrete instance of a search class
+     * Attempts to return a concrete instance of a class
      *
      * @access  public
-     * @param   string Type of Service. Can be one of search, autolink, asin and bookmarknum
+     * @param   string Type of Service. Can be one of search, autolink, asin, bookmarknum, bookmark, similar and photo
      * @return  object Concrete instance of a service class based on the paramter
      */
     public function create($type)
@@ -55,11 +55,12 @@ class Services_Hatena {
 
         switch ($type) {
 
-        case "search"      :
-        case "autolink"    :
-        case "bookmarknum" :
-        case "asin"        :
-        case "similar"     :
+        case "search"      : // i will make class for hatena search
+        case "autolink"    : // i will make class for autolink word
+        case "bookmarknum" : // i will make class for bookmarked count
+        case "asin"        : // i will make class for asin count
+        case "similar"     : // i will make class for similar word
+        case "bookmark"    : // i will make class for bookmark operate
             require_once(HATENA_BASEDIR . $type . ".php");
             $classname = "Services_Hatena_" . $type;
             return new $classname;
